@@ -12,6 +12,7 @@ from c8.keyvalue import KV
 from c8.collection import StandardCollection
 from c8.stream_apps import StreamApps
 from c8.apikeys import APIKeys
+from c8.search import Search
 from c8 import constants
 from c8.exceptions import (
     CollectionCreateError,
@@ -576,7 +577,10 @@ class Fabric(APIWrapper):
         :return: Standard collection API wrapper.
         :rtype: c8.collection.StandardCollection
         """
-        return StandardCollection(self._conn, self._executor, name)
+        if self.has_collection(name):
+            return StandardCollection(self._conn, self._executor, name)
+        else:
+            raise Exception("Collection not found")
 
     def has_collection(self, name):
         """Check if collection exists in the fabric.
@@ -586,7 +590,11 @@ class Fabric(APIWrapper):
         :return: True if collection exists, False otherwise.
         :rtype: bool
         """
-        return any(col['name'] == name for col in self.collections())
+        col = any(col['name'] == name for col in self.collections())
+        if not col:
+            raise Exception("Collection not found")
+        else:
+            return col
 
     def collections(self, collectionModel=None):
         """Return the collections in the fabric.
@@ -1459,8 +1467,15 @@ class Fabric(APIWrapper):
                 return resp.body['result']
         return self._execute(request, response_handler)
 
-
-    
+    ##############################
+    # Search, View and Analyzers #
+    ##############################
+    def search(self):
+        """Returns the Search APIWrapper
+        :return: Search API Wrapper
+        :rtype: c8.search.Search
+        """ 
+        return Search(self._conn, self._executor)
 
 class StandardFabric(Fabric):
     """Standard fabric API wrapper.
@@ -1692,4 +1707,4 @@ class TransactionFabric(Fabric):
             already committed.
         :raise c8.exceptions.TransactionExecuteError: If commit fails.
         """
-        return self._executor.commit()
\ No newline at end of file
+        return self._executor.commit()
